@@ -14,7 +14,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     FrameworkType,
@@ -73,18 +73,25 @@ class Exceptions:
     TooManyTagsException: Type[BotocoreClientError]
 
 
-class ManagedBlockchainClient:
+class ManagedBlockchainClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ManagedBlockchainClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#can_paginate)
         """
 
@@ -94,10 +101,12 @@ class ManagedBlockchainClient:
         ClientRequestToken: str,
         InvitationId: str,
         NetworkId: str,
-        MemberConfiguration: MemberConfigurationTypeDef
+        MemberConfiguration: "MemberConfigurationTypeDef"
     ) -> CreateMemberOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_member)
+        Creates a member within a Managed Blockchain network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_member)
         """
 
@@ -109,13 +118,15 @@ class ManagedBlockchainClient:
         Framework: FrameworkType,
         FrameworkVersion: str,
         VotingPolicy: "VotingPolicyTypeDef",
-        MemberConfiguration: MemberConfigurationTypeDef,
+        MemberConfiguration: "MemberConfigurationTypeDef",
         Description: str = None,
-        FrameworkConfiguration: NetworkFrameworkConfigurationTypeDef = None,
+        FrameworkConfiguration: "NetworkFrameworkConfigurationTypeDef" = None,
         Tags: Dict[str, str] = None
     ) -> CreateNetworkOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_network)
+        Creates a new blockchain network using Amazon Managed Blockchain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_network)
         """
 
@@ -124,12 +135,14 @@ class ManagedBlockchainClient:
         *,
         ClientRequestToken: str,
         NetworkId: str,
-        NodeConfiguration: NodeConfigurationTypeDef,
+        NodeConfiguration: "NodeConfigurationTypeDef",
         MemberId: str = None,
         Tags: Dict[str, str] = None
     ) -> CreateNodeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_node)
+        Creates a node on the specified blockchain network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_node)
         """
 
@@ -144,19 +157,26 @@ class ManagedBlockchainClient:
         Tags: Dict[str, str] = None
     ) -> CreateProposalOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_proposal)
+        Creates a proposal for a change to the network that other members of the network
+        can vote on, for example, a proposal to add a new member to the network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.create_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#create_proposal)
         """
 
     def delete_member(self, *, NetworkId: str, MemberId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_member)
+        Deletes a member.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#delete_member)
         """
 
     def delete_node(self, *, NetworkId: str, NodeId: str, MemberId: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_node)
+        Deletes a node that your AWS account owns.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.delete_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#delete_node)
         """
 
@@ -168,19 +188,25 @@ class ManagedBlockchainClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#generate_presigned_url)
         """
 
     def get_member(self, *, NetworkId: str, MemberId: str) -> GetMemberOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_member)
+        Returns detailed information about a member.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_member)
         """
 
     def get_network(self, *, NetworkId: str) -> GetNetworkOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_network)
+        Returns detailed information about a network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_network)
         """
 
@@ -188,13 +214,17 @@ class ManagedBlockchainClient:
         self, *, NetworkId: str, NodeId: str, MemberId: str = None
     ) -> GetNodeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_node)
+        Returns detailed information about a node.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_node)
         """
 
     def get_proposal(self, *, NetworkId: str, ProposalId: str) -> GetProposalOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_proposal)
+        Returns detailed information about a proposal.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.get_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#get_proposal)
         """
 
@@ -202,7 +232,9 @@ class ManagedBlockchainClient:
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListInvitationsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_invitations)
+        Returns a list of all invitations for the current AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_invitations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_invitations)
         """
 
@@ -217,7 +249,10 @@ class ManagedBlockchainClient:
         NextToken: str = None
     ) -> ListMembersOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_members)
+        Returns a list of the members in a network and properties of their
+        configurations.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_members)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_members)
         """
 
@@ -231,7 +266,10 @@ class ManagedBlockchainClient:
         NextToken: str = None
     ) -> ListNetworksOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_networks)
+        Returns information about the networks in which the current AWS account
+        participates.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_networks)
         """
 
@@ -245,7 +283,9 @@ class ManagedBlockchainClient:
         NextToken: str = None
     ) -> ListNodesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_nodes)
+        Returns information about the nodes within a network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_nodes)
         """
 
@@ -253,7 +293,10 @@ class ManagedBlockchainClient:
         self, *, NetworkId: str, ProposalId: str, MaxResults: int = None, NextToken: str = None
     ) -> ListProposalVotesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposal_votes)
+        Returns the list of votes for a specified proposal, including the value of each
+        vote and the unique identifier of the member that cast the vote.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposal_votes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_proposal_votes)
         """
 
@@ -261,31 +304,42 @@ class ManagedBlockchainClient:
         self, *, NetworkId: str, MaxResults: int = None, NextToken: str = None
     ) -> ListProposalsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposals)
+        Returns a list of proposals for the network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_proposals)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_proposals)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_tags_for_resource)
+        Returns a list of tags for the specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#list_tags_for_resource)
         """
 
     def reject_invitation(self, *, InvitationId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.reject_invitation)
+        Rejects an invitation to join a network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.reject_invitation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#reject_invitation)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.tag_resource)
+        Adds or overwrites the specified tags for the specified Amazon Managed
+        Blockchain resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.untag_resource)
+        Removes the specified tags from the Amazon Managed Blockchain resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#untag_resource)
         """
 
@@ -297,7 +351,9 @@ class ManagedBlockchainClient:
         LogPublishingConfiguration: "MemberLogPublishingConfigurationTypeDef" = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_member)
+        Updates a member configuration with new parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_member)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#update_member)
         """
 
@@ -310,7 +366,9 @@ class ManagedBlockchainClient:
         LogPublishingConfiguration: "NodeLogPublishingConfigurationTypeDef" = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_node)
+        Updates a node configuration with new parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.update_node)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#update_node)
         """
 
@@ -318,6 +376,8 @@ class ManagedBlockchainClient:
         self, *, NetworkId: str, ProposalId: str, VoterMemberId: str, Vote: VoteValueType
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/managedblockchain.html#ManagedBlockchain.Client.vote_on_proposal)
+        Casts a vote for a specified `ProposalId` on behalf of a member.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.2/reference/services/managedblockchain.html#ManagedBlockchain.Client.vote_on_proposal)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_managedblockchain/client.html#vote_on_proposal)
         """
