@@ -37,7 +37,13 @@ EditionType = Literal["STANDARD", "STARTER"]
 FrameworkType = Literal["ETHEREUM", "HYPERLEDGER_FABRIC"]
 InvitationStatusType = Literal["ACCEPTED", "ACCEPTING", "EXPIRED", "PENDING", "REJECTED"]
 MemberStatusType = Literal[
-    "AVAILABLE", "CREATE_FAILED", "CREATING", "DELETED", "DELETING", "UPDATING"
+    "AVAILABLE",
+    "CREATE_FAILED",
+    "CREATING",
+    "DELETED",
+    "DELETING",
+    "INACCESSIBLE_ENCRYPTION_KEY",
+    "UPDATING",
 ]
 NetworkStatusType = Literal["AVAILABLE", "CREATE_FAILED", "CREATING", "DELETED", "DELETING"]
 NodeStatusType = Literal[
@@ -47,6 +53,7 @@ NodeStatusType = Literal[
     "DELETED",
     "DELETING",
     "FAILED",
+    "INACCESSIBLE_ENCRYPTION_KEY",
     "UNHEALTHY",
     "UPDATING",
 ]
