@@ -36,22 +36,39 @@ else:
 
 __all__ = (
     "ApprovalThresholdPolicyTypeDef",
+    "CreateMemberInputRequestTypeDef",
     "CreateMemberOutputTypeDef",
+    "CreateNetworkInputRequestTypeDef",
     "CreateNetworkOutputTypeDef",
+    "CreateNodeInputRequestTypeDef",
     "CreateNodeOutputTypeDef",
+    "CreateProposalInputRequestTypeDef",
     "CreateProposalOutputTypeDef",
+    "DeleteMemberInputRequestTypeDef",
+    "DeleteNodeInputRequestTypeDef",
+    "GetMemberInputRequestTypeDef",
     "GetMemberOutputTypeDef",
+    "GetNetworkInputRequestTypeDef",
     "GetNetworkOutputTypeDef",
+    "GetNodeInputRequestTypeDef",
     "GetNodeOutputTypeDef",
+    "GetProposalInputRequestTypeDef",
     "GetProposalOutputTypeDef",
     "InvitationTypeDef",
     "InviteActionTypeDef",
+    "ListInvitationsInputRequestTypeDef",
     "ListInvitationsOutputTypeDef",
+    "ListMembersInputRequestTypeDef",
     "ListMembersOutputTypeDef",
+    "ListNetworksInputRequestTypeDef",
     "ListNetworksOutputTypeDef",
+    "ListNodesInputRequestTypeDef",
     "ListNodesOutputTypeDef",
+    "ListProposalVotesInputRequestTypeDef",
     "ListProposalVotesOutputTypeDef",
+    "ListProposalsInputRequestTypeDef",
     "ListProposalsOutputTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LogConfigurationTypeDef",
     "LogConfigurationsTypeDef",
@@ -82,8 +99,14 @@ __all__ = (
     "ProposalActionsTypeDef",
     "ProposalSummaryTypeDef",
     "ProposalTypeDef",
+    "RejectInvitationInputRequestTypeDef",
     "RemoveActionTypeDef",
     "ResponseMetadataTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateMemberInputRequestTypeDef",
+    "UpdateNodeInputRequestTypeDef",
+    "VoteOnProposalInputRequestTypeDef",
     "VoteSummaryTypeDef",
     "VotingPolicyTypeDef",
 )
@@ -98,6 +121,16 @@ ApprovalThresholdPolicyTypeDef = TypedDict(
     total=False,
 )
 
+CreateMemberInputRequestTypeDef = TypedDict(
+    "CreateMemberInputRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "InvitationId": str,
+        "NetworkId": str,
+        "MemberConfiguration": "MemberConfigurationTypeDef",
+    },
+)
+
 CreateMemberOutputTypeDef = TypedDict(
     "CreateMemberOutputTypeDef",
     {
@@ -106,6 +139,34 @@ CreateMemberOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateNetworkInputRequestTypeDef = TypedDict(
+    "_RequiredCreateNetworkInputRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Name": str,
+        "Framework": FrameworkType,
+        "FrameworkVersion": str,
+        "VotingPolicy": "VotingPolicyTypeDef",
+        "MemberConfiguration": "MemberConfigurationTypeDef",
+    },
+)
+_OptionalCreateNetworkInputRequestTypeDef = TypedDict(
+    "_OptionalCreateNetworkInputRequestTypeDef",
+    {
+        "Description": str,
+        "FrameworkConfiguration": "NetworkFrameworkConfigurationTypeDef",
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateNetworkInputRequestTypeDef(
+    _RequiredCreateNetworkInputRequestTypeDef, _OptionalCreateNetworkInputRequestTypeDef
+):
+    pass
+
+
 CreateNetworkOutputTypeDef = TypedDict(
     "CreateNetworkOutputTypeDef",
     {
@@ -115,6 +176,30 @@ CreateNetworkOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateNodeInputRequestTypeDef = TypedDict(
+    "_RequiredCreateNodeInputRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "NetworkId": str,
+        "NodeConfiguration": "NodeConfigurationTypeDef",
+    },
+)
+_OptionalCreateNodeInputRequestTypeDef = TypedDict(
+    "_OptionalCreateNodeInputRequestTypeDef",
+    {
+        "MemberId": str,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateNodeInputRequestTypeDef(
+    _RequiredCreateNodeInputRequestTypeDef, _OptionalCreateNodeInputRequestTypeDef
+):
+    pass
+
+
 CreateNodeOutputTypeDef = TypedDict(
     "CreateNodeOutputTypeDef",
     {
@@ -123,6 +208,31 @@ CreateNodeOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateProposalInputRequestTypeDef = TypedDict(
+    "_RequiredCreateProposalInputRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "NetworkId": str,
+        "MemberId": str,
+        "Actions": "ProposalActionsTypeDef",
+    },
+)
+_OptionalCreateProposalInputRequestTypeDef = TypedDict(
+    "_OptionalCreateProposalInputRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateProposalInputRequestTypeDef(
+    _RequiredCreateProposalInputRequestTypeDef, _OptionalCreateProposalInputRequestTypeDef
+):
+    pass
+
+
 CreateProposalOutputTypeDef = TypedDict(
     "CreateProposalOutputTypeDef",
     {
@@ -131,6 +241,44 @@ CreateProposalOutputTypeDef = TypedDict(
     },
 )
 
+DeleteMemberInputRequestTypeDef = TypedDict(
+    "DeleteMemberInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+    },
+)
+
+_RequiredDeleteNodeInputRequestTypeDef = TypedDict(
+    "_RequiredDeleteNodeInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "NodeId": str,
+    },
+)
+_OptionalDeleteNodeInputRequestTypeDef = TypedDict(
+    "_OptionalDeleteNodeInputRequestTypeDef",
+    {
+        "MemberId": str,
+    },
+    total=False,
+)
+
+
+class DeleteNodeInputRequestTypeDef(
+    _RequiredDeleteNodeInputRequestTypeDef, _OptionalDeleteNodeInputRequestTypeDef
+):
+    pass
+
+
+GetMemberInputRequestTypeDef = TypedDict(
+    "GetMemberInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+    },
+)
+
 GetMemberOutputTypeDef = TypedDict(
     "GetMemberOutputTypeDef",
     {
@@ -139,6 +287,13 @@ GetMemberOutputTypeDef = TypedDict(
     },
 )
 
+GetNetworkInputRequestTypeDef = TypedDict(
+    "GetNetworkInputRequestTypeDef",
+    {
+        "NetworkId": str,
+    },
+)
+
 GetNetworkOutputTypeDef = TypedDict(
     "GetNetworkOutputTypeDef",
     {
@@ -147,6 +302,28 @@ GetNetworkOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredGetNodeInputRequestTypeDef = TypedDict(
+    "_RequiredGetNodeInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "NodeId": str,
+    },
+)
+_OptionalGetNodeInputRequestTypeDef = TypedDict(
+    "_OptionalGetNodeInputRequestTypeDef",
+    {
+        "MemberId": str,
+    },
+    total=False,
+)
+
+
+class GetNodeInputRequestTypeDef(
+    _RequiredGetNodeInputRequestTypeDef, _OptionalGetNodeInputRequestTypeDef
+):
+    pass
+
+
 GetNodeOutputTypeDef = TypedDict(
     "GetNodeOutputTypeDef",
     {
@@ -155,6 +332,14 @@ GetNodeOutputTypeDef = TypedDict(
     },
 )
 
+GetProposalInputRequestTypeDef = TypedDict(
+    "GetProposalInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "ProposalId": str,
+    },
+)
+
 GetProposalOutputTypeDef = TypedDict(
     "GetProposalOutputTypeDef",
     {
@@ -183,6 +368,15 @@ InviteActionTypeDef = TypedDict(
     },
 )
 
+ListInvitationsInputRequestTypeDef = TypedDict(
+    "ListInvitationsInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListInvitationsOutputTypeDef = TypedDict(
     "ListInvitationsOutputTypeDef",
     {
@@ -192,6 +386,31 @@ ListInvitationsOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListMembersInputRequestTypeDef = TypedDict(
+    "_RequiredListMembersInputRequestTypeDef",
+    {
+        "NetworkId": str,
+    },
+)
+_OptionalListMembersInputRequestTypeDef = TypedDict(
+    "_OptionalListMembersInputRequestTypeDef",
+    {
+        "Name": str,
+        "Status": MemberStatusType,
+        "IsOwned": bool,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListMembersInputRequestTypeDef(
+    _RequiredListMembersInputRequestTypeDef, _OptionalListMembersInputRequestTypeDef
+):
+    pass
+
+
 ListMembersOutputTypeDef = TypedDict(
     "ListMembersOutputTypeDef",
     {
@@ -201,6 +420,18 @@ ListMembersOutputTypeDef = TypedDict(
     },
 )
 
+ListNetworksInputRequestTypeDef = TypedDict(
+    "ListNetworksInputRequestTypeDef",
+    {
+        "Name": str,
+        "Framework": FrameworkType,
+        "Status": NetworkStatusType,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListNetworksOutputTypeDef = TypedDict(
     "ListNetworksOutputTypeDef",
     {
@@ -210,6 +441,30 @@ ListNetworksOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListNodesInputRequestTypeDef = TypedDict(
+    "_RequiredListNodesInputRequestTypeDef",
+    {
+        "NetworkId": str,
+    },
+)
+_OptionalListNodesInputRequestTypeDef = TypedDict(
+    "_OptionalListNodesInputRequestTypeDef",
+    {
+        "MemberId": str,
+        "Status": NodeStatusType,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListNodesInputRequestTypeDef(
+    _RequiredListNodesInputRequestTypeDef, _OptionalListNodesInputRequestTypeDef
+):
+    pass
+
+
 ListNodesOutputTypeDef = TypedDict(
     "ListNodesOutputTypeDef",
     {
@@ -219,6 +474,29 @@ ListNodesOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListProposalVotesInputRequestTypeDef = TypedDict(
+    "_RequiredListProposalVotesInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "ProposalId": str,
+    },
+)
+_OptionalListProposalVotesInputRequestTypeDef = TypedDict(
+    "_OptionalListProposalVotesInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListProposalVotesInputRequestTypeDef(
+    _RequiredListProposalVotesInputRequestTypeDef, _OptionalListProposalVotesInputRequestTypeDef
+):
+    pass
+
+
 ListProposalVotesOutputTypeDef = TypedDict(
     "ListProposalVotesOutputTypeDef",
     {
@@ -228,6 +506,28 @@ ListProposalVotesOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListProposalsInputRequestTypeDef = TypedDict(
+    "_RequiredListProposalsInputRequestTypeDef",
+    {
+        "NetworkId": str,
+    },
+)
+_OptionalListProposalsInputRequestTypeDef = TypedDict(
+    "_OptionalListProposalsInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListProposalsInputRequestTypeDef(
+    _RequiredListProposalsInputRequestTypeDef, _OptionalListProposalsInputRequestTypeDef
+):
+    pass
+
+
 ListProposalsOutputTypeDef = TypedDict(
     "ListProposalsOutputTypeDef",
     {
@@ -237,12 +537,19 @@ ListProposalsOutputTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LogConfigurationTypeDef = TypedDict(
@@ -274,6 +581,7 @@ _OptionalMemberConfigurationTypeDef = TypedDict(
         "Description": str,
         "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
         "Tags": Dict[str, str],
+        "KmsKeyArn": str,
     },
     total=False,
 )
@@ -361,6 +669,7 @@ MemberTypeDef = TypedDict(
         "CreationDate": datetime,
         "Tags": Dict[str, str],
         "Arn": str,
+        "KmsKeyArn": str,
     },
     total=False,
 )
@@ -535,6 +844,7 @@ NodeTypeDef = TypedDict(
         "CreationDate": datetime,
         "Tags": Dict[str, str],
         "Arn": str,
+        "KmsKeyArn": str,
     },
     total=False,
 )
@@ -584,6 +894,13 @@ ProposalTypeDef = TypedDict(
     total=False,
 )
 
+RejectInvitationInputRequestTypeDef = TypedDict(
+    "RejectInvitationInputRequestTypeDef",
+    {
+        "InvitationId": str,
+    },
+)
+
 RemoveActionTypeDef = TypedDict(
     "RemoveActionTypeDef",
     {
@@ -602,6 +919,77 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+_RequiredUpdateMemberInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateMemberInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "MemberId": str,
+    },
+)
+_OptionalUpdateMemberInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateMemberInputRequestTypeDef",
+    {
+        "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateMemberInputRequestTypeDef(
+    _RequiredUpdateMemberInputRequestTypeDef, _OptionalUpdateMemberInputRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateNodeInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateNodeInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "NodeId": str,
+    },
+)
+_OptionalUpdateNodeInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateNodeInputRequestTypeDef",
+    {
+        "MemberId": str,
+        "LogPublishingConfiguration": "NodeLogPublishingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateNodeInputRequestTypeDef(
+    _RequiredUpdateNodeInputRequestTypeDef, _OptionalUpdateNodeInputRequestTypeDef
+):
+    pass
+
+
+VoteOnProposalInputRequestTypeDef = TypedDict(
+    "VoteOnProposalInputRequestTypeDef",
+    {
+        "NetworkId": str,
+        "ProposalId": str,
+        "VoterMemberId": str,
+        "Vote": VoteValueType,
+    },
+)
+
 VoteSummaryTypeDef = TypedDict(
     "VoteSummaryTypeDef",
     {
